package org.artifactory.metadata.service.provider;

import com.google.common.collect.ImmutableSet;
import lombok.Data;
import org.artifactory.descriptor.repo.RepoType;
import org.artifactory.md.Properties;
import org.artifactory.repo.RepoPath;
import org.springframework.stereotype.Component;

import javax.annotation.Nullable;
import java.util.Optional;
import java.util.Set;

/**
 * @author Uriah Levy
 */
@Component
public class DebianMetadataProvider extends AbstractMetadataProvider {
    private static final RepoType type = RepoType.Debian;
    private static final Set<String> LEAD_FILE_EXTENSIONS = ImmutableSet.of("deb", "ddeb");

    DebianMetadataProvider() {
        super(type);
        setTypeSpecificMetadataTemplate(new DebianTypeSpecificMetadataTemplate());
    }

    @Override
    protected String getType() {
        return type.getPkgidPrefix();
    }

    @Data
    class DebianTypeSpecificMetadataTemplate implements TypeSpecificMetadataTemplate {
        private static final String DEB = "deb";
        private static final String NAME_SUFFIX = ".name";
        private static final String VERSION_SUFFIX = ".version";
        private static final String DISTRIBUTION = ".distribution";
        private static final String ARCHITECTURE = ".architecture";
        private Set<String> excludedUserProperties = ImmutableSet
                .of(DEB + NAME_SUFFIX, DEB + VERSION_SUFFIX);

        @Override
        public Optional<String> getNameKey() {
            return Optional.of(DEB + NAME_SUFFIX);
        }

        @Override
        public Optional<String> getVersionKey() {
            return Optional.of(DEB + VERSION_SUFFIX);
        }

        @Override
        public Set<String> getExcludedUserProperties() {
            return excludedUserProperties;
        }

        @Override
        public Set<String> getLeadFileExtensions() {
            return LEAD_FILE_EXTENSIONS;
        }

        @Override
        public Optional<String> getArchitectureKey() {
            return Optional.of(DEB + ARCHITECTURE);
        }

        @Override
        public Optional<String> getDistributionKey() {
            return Optional.of(DEB + DISTRIBUTION);
        }

        @Override
        public String getName(Properties properties, RepoPath repoPath) {
            return getNameKey().map(nameKey -> valueForKey(properties, nameKey)).orElse(null);
        }

        @Nullable
        @Override
        public String getVersion(RepoPath repoPath, Properties properties) {
            return getVersionKey().map(versionKey -> valueForKey(properties, versionKey)).orElse(null);
        }

        @Nullable
        @Override
        public String getPkgidSuffix(RepoPath repoPath, Properties properties) {
            return getNameKey().map(nameKey -> valueForKey(properties, nameKey)).orElse(null);
        }
    }
}
