package org.artifactory.repo.interceptor;

import org.artifactory.api.context.ContextHelper;
import org.artifactory.api.security.AuthorizationService;
import org.artifactory.common.MutableStatusHolder;
import org.artifactory.pipelines.InternalPipelinesService;
import org.artifactory.repo.interceptor.storage.StorageInterceptorAdapter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.apache.http.HttpStatus.SC_FORBIDDEN;
import static org.artifactory.repo.system.SystemRepos.PIPEINFO_REPO_KEY;

/**
 * @author Alexei Vainshtein
 */

public class PipelinesInterceptor extends StorageInterceptorAdapter {
    private static final Logger log = LoggerFactory.getLogger(PipelinesInterceptor.class);

    @Override
    public void assertDeleteRepoAllowed(String repoKey, MutableStatusHolder status) {
        if (PIPEINFO_REPO_KEY.equals(repoKey)) {
            status.error("Deletion of Pipe-Info repository " + repoKey + " is not allowed.", SC_FORBIDDEN, log);
            return;
        }
        InternalPipelinesService pipelinesService = ContextHelper.get().beanForType(InternalPipelinesService.class);
        AuthorizationService authService = ContextHelper.get().getAuthorizationService();
        if (pipelinesService.isPipeInfoRepo(repoKey) && !authService.isAdmin()) {
            status.error("Deletion of Pipe-Info repository '" + repoKey + "' is restricted only for super admin.",
                    SC_FORBIDDEN, log);
        }
    }
}
