package org.artifactory.schedule;

import org.artifactory.api.context.ArtifactoryContext;
import org.artifactory.api.context.ArtifactoryContextThreadBinder;
import org.artifactory.test.ArtifactoryHomeBoundTest;
import org.mockito.Mockito;
import org.quartz.Scheduler;
import org.quartz.SchedulerException;
import org.testng.Assert;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

/**
 * @author Alexei Vainshtein
 */
public class TaskServiceImplTest extends ArtifactoryHomeBoundTest {

    private TaskServiceImpl taskService;

    @BeforeMethod
    public void setup() {
        taskService = new TaskServiceImpl();
    }

    @Test
    public void testRescheduleTask() throws SchedulerException {
        InternalTask task1 = (InternalTask)TaskUtils.createCronTask(DummyQuartzCommand.class, "* * * * * ?");
        ArtifactoryContext context = Mockito.mock(ArtifactoryContext.class);

        try {
            ArtifactoryContextThreadBinder.bind(context);
            taskService.startTask(task1, false);
            Mockito.when(context.isReady()).thenReturn(true);
            Scheduler scheduler = Mockito.mock(Scheduler.class);
            Mockito.when(context.beanForType(Scheduler.class)).thenReturn(scheduler);
            taskService.onContextReady();
            task1.setShouldRescheduleTask(true);
            Assert.assertNotNull(taskService.getActiveTask(task1.getToken(), true));
            taskService.rescheduleTask(task1.getToken());
            Mockito.verify(scheduler, Mockito.times(1)).deleteJob(Mockito.any());
            Mockito.verify(scheduler, Mockito.times(2)).scheduleJob(Mockito.any(), Mockito.any());
            Assert.assertNotNull(taskService.getActiveTask(task1.getToken(), true));
            Assert.assertFalse(task1.shouldRescheduleTask());
        } finally {
            ArtifactoryContextThreadBinder.unbind();
        }
    }
}