#!/usr/bin/env bash

set -e

export PROJECT_ROOT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && cd ../../.. && pwd)"
MODULES_TO_TEST="${MODULES_TO_TEST:-}"

function on_start() {
    cd "${PROJECT_ROOT_DIR}/artifactory-oss"
    local cache_dir="${run_dir}/${step_affinity_group}_cache_classes"
    local state_cache_dir="${PROJECT_ROOT_DIR}/artifactory-oss"
    local run_state_cache_dir="${cache_dir}/dir_cache"
    cd ${state_cache_dir}
    ${PROJECT_ROOT_DIR}/build/ci/scripts/javaGenerateConfig.sh
    export MAVEN_PHASE="test"
    if pipeline_shouldRunSonar ; then
        MAVEN_PHASE="jacoco:prepare-agent surefire:test jacoco:report -Psonar"
    fi
    export MAVEN_EXTRA_CONFIG=""
    if [ -d "${run_state_cache_dir}" ] && cp -r "${run_state_cache_dir}"/* "${state_cache_dir}" ; then
        echo "Dir state was restored." >&2
        MAVEN_EXTRA_CONFIG="${MAVEN_EXTRA_CONFIG} -Denforcer.skip=true -Dcheckstyle.skip=true -Dmaven.resources.skip=true"
    else # In case running tests without build we are building and running all tests
        source "${PROJECT_ROOT_DIR}/build/ci/scripts/lib/buildInfoUtils.sh"
        source "${PROJECT_ROOT_DIR}/build/ci/scripts/lib/versionUtils.sh"
        source "${PROJECT_ROOT_DIR}/build/ci/scripts/lib/mavenUtils.sh"
        local version revision
        version=$(maven_getVersionFromPom pom.xml)
        revision=$(version_getRevisionFromVersion ${version})
        "${PROJECT_ROOT_DIR}/build/ci/scripts/javaGenerateConfig.sh"
        buildInfo_setBuildNameAndNumber

        MAVEN_PHASE="install -Dartifactory.revision.prop=${revision}"
        if pipeline_shouldRunSonar ; then
            MAVEN_PHASE="jacoco:prepare-agent install jacoco:report -Psonar -Dartifactory.revision.prop=${revision}"
        fi
    fi
    export MVN_COMMAND="${MAVEN_PHASE} -P!frontend -T 2 -Dartifactory.publish.artifacts=false ${MAVEN_EXTRA_CONFIG} ${MAVEN_CONFIG}"
}

function on_complete() {
    ${PROJECT_ROOT_DIR}/build/ci/scripts/mvnCollectTestResults.sh artifactory-oss ./junittests
    save_tests ./junittests
}

function on_success() {
  if pipeline_shouldRunSonar ; then
    source "${PROJECT_ROOT_DIR}/build/ci/scripts/runSonarScannerGeneric.sh"
    sonar_storeCache "${PROJECT_ROOT_DIR}/artifactory-oss"
  fi
}
