/*
 *
 * Artifactory is a binaries repository manager.
 * Copyright (C) 2018 JFrog Ltd.
 *
 * Artifactory is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 * Artifactory is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Artifactory.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package org.artifactory.rest.resource.replicator;

import org.artifactory.addon.AddonsManager;
import org.artifactory.api.replicator.P2pLicenseCheckResponse;
import org.artifactory.api.security.AuthorizationService;
import org.artifactory.entitlement.EntitlementType;
import org.joda.time.DateTime;
import org.joda.time.format.ISODateTimeFormat;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.annotation.security.RolesAllowed;
import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import java.util.Date;

import static org.artifactory.api.rest.constant.ReplicatorRestConstants.PATH_LICENSE_CHECK;
import static org.artifactory.api.rest.constant.ReplicatorRestConstants.PATH_P2P_ROOT;

/**
 * TODO: Remove
 */
@Component
@Path(PATH_P2P_ROOT)
@RolesAllowed({AuthorizationService.ROLE_ADMIN})
public class P2pResource {

    @Autowired
    private AddonsManager addonsManager;

    @Context
    private HttpServletRequest request;

    @GET
    @Path(PATH_LICENSE_CHECK)
    @Produces({MediaType.APPLICATION_JSON})
    public Response checkLicense() {
        if (!addonsManager.isLicenseInstalled()) {
            return Response.status(Response.Status.SERVICE_UNAVAILABLE)
                    .entity("No license is installed")
                    .build();
        }
        P2pLicenseCheckResponse.Builder builder = P2pLicenseCheckResponse.builder()
                .p2pAllowedByLicense(addonsManager.isEntitled(EntitlementType.PDN));

        Date licenseValidUntil = addonsManager.getLicenseValidUntil();
        if (licenseValidUntil != null) {
            builder.validUntil(ISODateTimeFormat.dateTime().print(new DateTime(licenseValidUntil)));
        }
        return Response.ok(builder.build()).build();
    }
}